@@ -16,12 +16,12 @@ to build and distribute their templates as plugins, not to mention the fact
 that tayra's implementation itself is heavily based on plugins.
 """
     
-from   os.path            import dirname, join, basename
+from   os.path            import dirname, join, basename, abspath, isfile
 
 from   pluggdapps.plugin  import Plugin, ISettings
 import pluggdapps.utils   as h
 
-__version__ = '0.4dev'
+__version__ = '0.41dev'
 
 template_plugins = [
     'tayra:test/stdttl/implementer.ttl'
@@ -46,8 +46,8 @@ def loadttls( pa, ttlfiles, compiler_setts={} ):
     """
 
     for ttlfile in ttlfiles :
-        compiler = pa.query_plugin( pa, ISettings, 'ttlcompiler',
-                                    settings=compiler_setts )
+        compiler = pa.qp(
+                pa, ISettings, 'tayra.ttlcompiler', settings=compiler_setts )
         code = compiler.compilettl( file=ttlfile )
         compiler.load( code, context={} )
         pa.logdebug( "Loaded template plugin %r ..." % ttlfile )
@@ -73,8 +73,19 @@ def translatefile( ttlfile, compiler, options ):
     """
     args = getattr( options, 'args', [] )
     args = eval( args ) if isinstance( args, str ) else args
-    context = getattr( options, 'context', {} )
-    context = eval( context ) if isinstance( context, str ) else context
+
+    # Update context
+    context = getattr( options, 'context', '{}' ).strip()
+    try :
+        context = eval(context)
+    except :
+        try :
+            cxtfile = abspath( context )
+            if isfile( cxtfile ) :
+                context = eval( open( cxtfile ).read().strip() )
+        except :
+            context = {}
+
     context.update( _bodyargs=args )
 
     # Generate
@@ -121,3 +132,5 @@ import tayra.interfaces     # Import interfaces specified by tayra project.
 import tayra.tags           # Import plugins implementing ITayraTags
 import tayra.filterblocks   # Import plugins implementing ITayraFilterBlock
 import tayra.expr           # Import plugins implementing ITayraExpression
+
+
