@@ -6,18 +6,17 @@
 # file 'LICENSE', which is part of this source code package.
 #       Copyright (c) 2011 R Pratap Chakravarthy
 
-"""Lexing rules for Tayra Template Language"""
+"""Lexing rules for Tayra Template Language. Lexer uses
+`PLY <http://www.dabeaz.com/ply>`_."""
 
 import re, sys, os
 import ply.lex
 from   ply.lex          import TOKEN, LexToken
 
 class TTLLexer( object ) :
-    """A lexer for the Tayra Template language
-        build() To build   
-        input() Set the input text
-        token() To get new tokens.
-    """
+    """Lexical analyser for tayra templates. This class is initialized
+    with :class:`tayra.compiler.TTLCompiler` instance."""
+
     def __init__( self, compiler ):
         """ Create a new Lexer"""
         self.compiler = compiler
@@ -28,44 +27,57 @@ class TTLLexer( object ) :
     #---- API methods
 
     def build( self, **kwargs ) :
-        """ Builds the lexer from the specification. Must be called after the
-        lexer object is created. This method exists separately, because the
-        PLY manual warns against calling lex.lex inside __init__
+        """Builds the lexer from this class specification. Must be called
+        after the lexer object is created. This method exists separately,
+        because the PLY manual warns against calling lex.lex inside __init__
         """
         self.ttlfile = kwargs.pop( 'ttlfile', '<String>' )
         reflags = re.MULTILINE | re.UNICODE
         self.lexer = ply.lex.lex( module=self, reflags=reflags, **kwargs )
 
     def input( self, text ) :
-        """`text` to tokenise. Preprocess the text before tokenising,
-          * A line separator is automatically appended at the end of text.
+        """Set the input text for tokenising. Input text is pre-processed
+        before. A line separator is automatically appended at the end of
+        text for convenient parsing.
         """
         self.lexer.input( self._preprocess( text ) + os.linesep ) #self.finish
     
     def token( self ) :
-        """Get the next token"""
+        """Get next token. Primary interface for the parser."""
         tok = self.poptoken()
         tok = self.lexer.token() if tok == None else tok
         if tok == None and self.indentstack :
             self._unwind_indentstack()
             tok = self.poptoken()
+        if tok :
+            tok.value = (tok.value, tok.lineno)
         return tok 
 
     def reset_lineno( self ) :
-        """ Resets the internal line number counter of the lexer."""
+        """Resets the internal line number counter of the lexer."""
         self.lexer.lineno = 1
+ 
+    #---- Local methods
 
     def poptoken( self ) :
         tok = self.ttltokens.pop(0) if self.ttltokens else None
         return tok
 
-    #---- States
+    def replacetab( self, s ):
+        return s.replace( '\t', ' '*self.tab2space )
+
+    def indentby( self, here, to ):
+        return ' ' * (len(here) - currlevel)
+
+    #---- Lexer states
+
     states = ( 
         ( 'comment', 'exclusive' ),
         ( 'filter', 'exclusive' ),
     )
 
-    #---- Tokens
+    #---- Token types
+
     tokens = (
         # Tokens
         'INDENT', 'DEDENT', 'NEWLINES', 'TEXT',
@@ -102,8 +114,8 @@ class TTLLexer( object ) :
         r'(?:"[^"\\]*(?:\\.[^"\\]*)*")'+r'|'+r"(?:'[^'\\]*(?:\\.[^'\\]*)*')"
     finish    = r'OVER!!!!@\#END-OF-TEXT\#@!!!!OVER'
     prgsuffx  = r'(?=:[ \t]*$):[ \t]*$'
-    text      = r'[^\r\n\\]+'
-    exprsubst = r'(?<!\\)\$\{[^}]*\}'
+    text      = r'[^<\r\n\\]+'
+    exprsubst = r'(?<!\\)\$\{[^}\\]*(?:\\.[^}\\]*)*\}'
 
     # Single line statements
     statement   = r'@@[^\r\n]+$'
@@ -146,18 +158,8 @@ class TTLLexer( object ) :
     tagchar     = r'([^>\\]|\r|\n|\r\n)'
     newtag      = r'<(%s)?%s*(?:\\.%s*)*>' % (tagmodifs, tagchar, tagchar)
 
-    def replacetab( self, s ):
-        return s.replace( '\t', ' '*self.tab2space )
-
-    def indentby( self, here, to ):
-        return ' ' * (len(here) - currlevel)
-
     #---- Generic tokens
 
-    #@TOKEN( finish )
-    #def t_FINISH_TEXT( self, t ) :
-    #    return t
-
     @TOKEN( escseq )
     def t_ESCAPED( self, t ) :
         return self._onescaped( t )
@@ -231,58 +233,58 @@ class TTLLexer( object ) :
         return t
 
     @TOKEN( cmtopen )                   # Open a comment block
-    def t_COMMENTOPEN( self, t ) :
+    def t_COMMENTOPEN( self, t ):
         t.lexer.push_state( 'comment' )
         return t
 
     @TOKEN( fbopen )
-    def t_FILTEROPEN( self, t ) :
+    def t_FILTEROPEN( self, t ):
         t.lexer.push_state( 'filter' )
         return t
 
     @TOKEN( interface )
-    def t_INTERFACE( self, t ) :
+    def t_INTERFACE( self, t ):
         self._incrlineno(t)
         return t
 
     @TOKEN( decorator )
-    def t_DECORATOR( self, t ) :
+    def t_DECORATOR( self, t ):
         self._incrlineno(t)
         return t
 
     @TOKEN( function )
-    def t_FUNCTION( self, t ) :
+    def t_FUNCTION( self, t ):
         self._incrlineno(t)
         return t
 
     @TOKEN( if_ )
-    def t_IF( self, t ) :
+    def t_IF( self, t ):
         return t
 
     @TOKEN( elif_ )
-    def t_ELIF( self, t ) :
+    def t_ELIF( self, t ):
         return t
 
     @TOKEN( else_ )
-    def t_ELSE( self, t ) :
+    def t_ELSE( self, t ):
         return t
 
     @TOKEN( for_ )
-    def t_FOR( self, t ) :
+    def t_FOR( self, t ):
         return t
 
     @TOKEN( while_ )
-    def t_WHILE( self, t ) :
+    def t_WHILE( self, t ):
         return t
 
     @TOKEN( newtag )
-    def t_TAGBEGIN( self, t ) :
+    def t_TAGBEGIN( self, t ):
         self._incrlineno(t)
         t.value = t.value.replace( r'\>', '>' )
         return t
 
     @TOKEN( text )
-    def t_TEXT( self, t ) :
+    def t_TEXT( self, t ):
         return t
 
     #---- Comment block tokens
@@ -341,7 +343,7 @@ class TTLLexer( object ) :
         return ( token.lineno, self._find_tok_column(token) )
 
     def _incrlineno( self, token ) :
-        newlines = len( token.value.split('\n') ) - 1
+        newlines = len( re.findall( r'\n|\r\n|\r', token.value ))
         if newlines > 0 :
             token.lexer.lineno += newlines
     
@@ -354,6 +356,9 @@ class TTLLexer( object ) :
         return tok
 
     def _preprocess( self, text ) :
+        # Prune away empty lines in the beginning,
+        text = text.lstrip(' \t\r\n')
+        text = text.replace( '\\\n', '' )
         return text
 
     def _addtokens( self, tok ) :
